.. module:: brownie.functional

Functional
==========

This module provides functions known from functional programming
languages.

.. autofunction:: compose

.. autofunction:: flip

.. autoclass:: Signature
   :members:

.. autoclass:: curried
